@@ -10,6 +10,13 @@ class Distro(Module):
         )
 
 
+class Debian(Module):
+    def do_deploy(self, target, **kw):
+        return self.install(target,
+            pkg = 'pip setuptools venv',
+        )
+
+
 class FreeBSD_13(Distro):
     def do_deploy(self, target, **kw):
         return self.install(target,
